@@ -807,7 +807,7 @@ sub run_cc_test {
     open T, ">", $test; print T $script; close T;
     # Being able to test also the CORE B in older perls
     my $Mblib = $] >= 5.009005 ? Mblib() : "";
-    my $useshrplib = $Config{useshrplib} eq 'true';
+    my $useshrplib = $Config{useshrplib} =~ /^(true|yes)$/;
     unless ($Mblib) {           # check for -Mblib from the testsuite
         if (grep { m{blib(/|\\)arch$} } @INC) {
             $Mblib = Mblib();  # forced -Mblib via cmdline without
@@ -827,6 +827,7 @@ sub run_cc_test {
                     progfile => $test);
     if (! $? and -s $cfile) {
 	use ExtUtils::Embed ();
+	$ExtUtils::Embed::Verbose = 1 if $ENV{TEST_VERBOSE} and $ENV{TEST_VERBOSE} >= 2;
 	my $coredir = $ENV{PERL_CORE}
           ? File::Spec->catdir('..', '..')
           : File::Spec->catdir($Config{installarchlib}, "CORE");
@@ -847,6 +848,7 @@ sub run_cc_test {
             if ($Config{ccversion} eq '12.0.8804') {
                 $command =~ s/ -opt:ref,icf//;
             }
+            $command .= " -Od" if $ENV{APPVEYOR};
             my $obj = $obj[0];
             $command =~ s/ \Q-o $exe\E / -c -Fo$obj /;
             my $cmdline = "$Config{cc} $command >NUL"; # need to silence it
@@ -856,6 +858,7 @@ sub run_cc_test {
         }
 	my $libdir  = File::Spec->catdir($Config{prefix}, "lib");
         my $so = $Config{so};
+        my $libperl = $Config{libperl};
         my $pkg = ($Config{usecperl} and $libperl =~ /libcperl/) ? "cperl" : "perl";
         my $linkargs = $ENV{PERL_CORE}
           ? ExtUtils::Embed::_ccdlflags." ".ExtUtils::Embed::_ldflags()
@@ -880,19 +883,26 @@ sub run_cc_test {
                     $linkargs .= " $win32core";
                 }
             }
+            $linkargs .= " -Od" if $ENV{APPVEYOR};
         }
-	if ( -e "$coredir/$Config{libperl}" and $Config{libperl} !~ /\.$so$/) {
+	if ( -e "$coredir/$libperl" and $libperl !~ /\.$so$/) {
 	    $command .= $linkargs;
-	} elsif ( $useshrplib and (-e "$libdir/$Config{libperl}" or -e "/usr/lib/$Config{libperl}")) {
+	} elsif ( $useshrplib and (-e "$libdir/$libperl" or -e "/usr/lib/$libperl")) {
             # debian: /usr/lib/libperl.so.5.10.1 and broken ExtUtils::Embed::ldopts
-            if ($Config{libperl} =~ /\.$so$/) {
-                my $libperl = File::Spec->catfile($coredir, $Config{libperl});
-                $linkargs =~ s|-lperl |$libperl |; # link directly
+            if ($libperl =~ /\.$so$/) {
+                my $libperlpath = File::Spec->catfile($coredir, $libperl);
+                $linkargs =~ s|-lperl |$libperlpath |; # link directly
             }
 	    $command .= $linkargs;
 	} else {
 	    $command .= $linkargs;
-	    $command .= " -lperl" if $command !~ /(-lperl|CORE\/libperl5)/ and !$is_mswin;
+	    if ($command !~ /(-lc?perl|CORE\/libperl5)/ and !$is_mswin) {
+                if ($Config{usecperl} and $useshrplib) {
+                    $command .= " -lcperl";
+                } else {
+                    $command .= " -lperl";
+                }
+            }
 	}
 	$command .= $B::C::Config::extra_libs;
         my $NULL = $is_mswin ? '' : '2>/dev/null';
